! ----------------------------------------------------------------------------------------
! ----------------------------------------------------------------------------------------

SUBROUTINE Coor2Num(Coord, Axis, Num, ErCode) 
! ----------------------------------------------------------------------------------------

! PURPOSE: To convert coordinate in degrees to number of the nearest pixel of the bitmap
! AUTHOR:  Ekaterina Kourzeneva, 
!          RSHU, 2009
! INPUT: Coord - the coordinate value in DEGREES (with decimal digits!!!)
!        Axis  - the mark for the axis:  1 - longitude, Coord must be from -180 to 180
!                                        2 - latitude, Coord must be from -90 to 90
! USES: module Bitmap (Bitmap.f90)
! CALLS EXTERNAL SUBROUTINE(S) OR FUNCTION(S): no
! READS FILES: no
! OUTPUT: Num - the number of the nearest pixel of the bitmap
!         ErCode - error code  = 0 if no error
!                              = 1 if it is the error
! ----------------------------------------------------------------------------------------- 

 USE Bitmap, ONLY : &
  NlonB, & ! Number of longitude pixels of the bitmap
  NlatB, & ! Number of latitude pixels of the bitmap
  PixSize  ! Pixel size of the bitmap in seconds of arc
! ------------------------------------------------------------------------------------------

 IMPLICIT NONE
! ------------------------------------------------------------------------------------------

 REAL, INTENT(IN) :: Coord ! The coordinate in DEGREES (with decimal digits!!!)
 INTEGER, INTENT(IN) :: Axis ! The axis: 1 - longitude, degrees from -180 to 180
                             !           2 - latitude, degrees from -90 to 90
 INTEGER, INTENT(OUT) :: Num ! The number of the nearest pixel of the bitmap
 INTEGER, INTENT(OUT) :: ErCode ! Code of error = 0 if no error
                                !               = 1 if error
! -------------------------------------------------------------------------------------------

 REAL :: DPixSize ! Pixel size decimal
! ------------------------------------------------------------------------------------------- 
 

 DPixSize=PixSize/3600.

 SELECT CASE(Axis) ! Choose axis
  CASE (1)
   IF(Coord.LT.-180..OR.Coord.GT.180.) THEN
    Num=0
    write(*,*) 'Longitude should be within the interval of -180 to 180'
    ErCode = 1
    RETURN
   END IF
   Num=INT((180.+MIN(Coord,179.999))*3600/PixSize)+1
   ErCode = 0
  CASE (2)
   IF(Coord.LT.-90..OR.Coord.GT.90.) THEN
    Num=0
    write(*,*) 'Latitude should be within the interval of -90 to 90.'
    ErCode = 1
    RETURN
   END IF
    Num=NlatB-(INT((90.+MIN(Coord,89.999))*3600/PixSize)+1)+1 
    ErCode = 0
  CASE DEFAULT
   Num=0
   write(*,*) 'Latitude or Longitude? Wrong number of axis!'
   ErCode = 1
   RETURN
 END SELECT ! Choose axis
! --------------------------------------------------------------------------------


END SUBROUTINE Coor2Num
! --------------------------------------------------------------------------------
! --------------------------------------------------------------------------------


